@@ -1,6 +1,8 @@
 package ArangoDB::Index;
 use strict;
 use warnings;
+use utf8;
+use 5.008001;
 use Carp qw(croak);
 use Scalar::Util qw(weaken);
 use ArangoDB::Constants qw(:api);
